@@ -1,4 +1,8 @@
+#' @autoglobal
 build_copy_queries <- function(dest, dm, set_key_constraints = TRUE, temporary = TRUE, table_names = set_names(names(dm))) {
+  ## use 0-rows object
+  ptype_dm <- collect(dm_ptype(dm))
+
   con <- con_from_src_or_con(dest)
 
   ## helper to quote all elements of a column and enumerate (concat) element wise
@@ -6,9 +10,20 @@ build_copy_queries <- function(dest, dm, set_key_constraints = TRUE, temporary =
     map_chr(x, ~ toString(map_chr(.x, DBI::dbQuoteIdentifier, conn = con)))
   }
 
+  ## helper to set on delete statement for fks if required
+  set_on_delete_col <- function(x) {
+    map_chr(x, ~ {
+      switch(.x,
+        "no_action" = "",
+        "cascade" = " ON DELETE CASCADE",
+        abort(glue("on_delete column value '{.x}' not supported"))
+      )
+    })
+  }
+
   ## fetch types, keys and uniques
-  pks <- dm_get_all_pks_impl(dm) %>% rename(name = table)
-  fks <- dm_get_all_fks_impl(dm)
+  pks <- dm_get_all_pks_impl(ptype_dm) %>% rename(name = table)
+  fks <- dm_get_all_fks_impl(ptype_dm)
 
   # if a that doesn't match a pk, this non-pk col should be unique
   uniques <-
@@ -24,12 +39,12 @@ build_copy_queries <- function(dest, dm, set_key_constraints = TRUE, temporary =
     # autoincrementing is not possible for composite keys, so `pk_col` is guaranteed
     # to be a scalar
     pk_col <-
-      dm %>%
+      ptype_dm %>%
       dm_get_all_pks(!!x) %>%
       filter(autoincrement) %>%
       pull(pk_col)
 
-    tbl <- tbl_impl(dm, x)
+    tbl <- tbl_impl(ptype_dm, x)
     types <- DBI::dbDataType(con, tbl)
     autoincrement_attribute <- ""
 
@@ -53,7 +68,7 @@ build_copy_queries <- function(dest, dm, set_key_constraints = TRUE, temporary =
 
       # SQL Server:
       if (is_mssql(dest)) {
-        types[pk_col] <- "INT IDENTITY"
+        types[pk_col] <- paste0(types[pk_col], " IDENTITY")
       }
 
       # MariaDB:
@@ -90,7 +105,7 @@ build_copy_queries <- function(dest, dm, set_key_constraints = TRUE, temporary =
   }
 
   col_defs <-
-    dm %>%
+    ptype_dm %>%
     src_tbls_impl() %>%
     set_names() %>%
     map_dfr(get_sql_col_types, .id = "name") %>%
@@ -136,11 +151,7 @@ build_copy_queries <- function(dest, dm, set_key_constraints = TRUE, temporary =
 
     # foreign key definitions and indexing queries
     # https://github.com/r-lib/rlang/issues/1422
-    if (is_duckdb(con) && package_version(asNamespace("duckdb")$.__NAMESPACE__.$spec[["version"]]) < "0.3.4.1") {
-      if (nrow(fks)) {
-        warn("duckdb doesn't support foreign keys, these won't be set in the remote database but are preserved in the `dm`")
-      }
-    } else if (is_mariadb(con) && temporary) {
+    if (is_mariadb(con) && temporary) {
       if (nrow(fks) > 0 && !is_testing()) {
         warn("MySQL and MariaDB don't support foreign keys for temporary tables, these won't be set in the remote database but are preserved in the `dm`")
       }
@@ -153,10 +164,11 @@ build_copy_queries <- function(dest, dm, set_key_constraints = TRUE, temporary =
             "FOREIGN KEY (",
             quote_enum_col(child_fk_cols),
             ") REFERENCES ",
-            unlist(table_names[parent_table]),
+            purrr::map_chr(table_names[fks$parent_table], ~ DBI::dbQuoteIdentifier(con, .x)),
             " (",
             quote_enum_col(parent_key_cols),
-            ")"
+            ")",
+            set_on_delete_col(on_delete)
           )
         ) %>%
         group_by(name) %>%
@@ -167,7 +179,7 @@ build_copy_queries <- function(dest, dm, set_key_constraints = TRUE, temporary =
         mutate(
           name = child_table,
           index_name = map_chr(child_fk_cols, paste, collapse = "_"),
-          remote_name = unlist(table_names[name]) %||% character(0),
+          remote_name = purrr::map_chr(table_names[name], ~ DBI::dbQuoteIdentifier(con, .x)),
           remote_name_unquoted = map_chr(DBI::dbUnquoteIdentifier(con, DBI::SQL(remote_name)), ~ .x@name[["table"]]),
           index_name = make.unique(paste0(remote_name_unquoted, "__", index_name), sep = "__")
         ) %>%
@@ -206,7 +218,7 @@ build_copy_queries <- function(dest, dm, set_key_constraints = TRUE, temporary =
     ) %>%
     ungroup() %>%
     transmute(name, remote_name, columns, sql_table = DBI::SQL(glue(
-      "CREATE {if (temporary) 'TEMPORARY ' else ''}TABLE {unlist(remote_name)} (\n  {all_defs}\n)"
+      "CREATE {if (temporary) 'TEMPORARY ' else ''}TABLE {purrr::map_chr(remote_name, ~ DBI::dbQuoteIdentifier(con, .x))} (\n  {all_defs}\n)"
     )))
 
   queries <- left_join(create_table_queries, index_queries, by = "name")
