@@ -16,6 +16,16 @@
 #'   foreign keys from the database.
 #'   Currently works only for Postgres and SQL Server databases.
 #'   The default attempts to query and issues an informative message.
+#' @param .names
+#'   `r lifecycle::badge("experimental")`
+#'
+#'   A glue specification that describes how to name the tables
+#'   within the output, currently only for MSSQL, Postgres and MySQL/MariaDB.
+#'   This can use `{.table}` to stand for the table name, and
+#'   `{.schema}` to stand for the name of the schema which the table lives
+#'   within. The default (`NULL`) is equivalent to `"{.table}"` when a single
+#'   schema is specified in `schema`, and `"{.schema}.{.table}"` for the case
+#'   where multiple schemas are given, and may change in future versions.
 #' @param ... `r lifecycle::badge("experimental")`
 #'
 #'   Additional parameters for the schema learning query.
@@ -40,7 +50,7 @@
 #'
 #' # Avoid DBI::dbDisconnect() here, because we don't own the connection
 dm_from_con <- function(con = NULL, table_names = NULL, learn_keys = NULL,
-                        ...) {
+                        .names = NULL, ...) {
   stopifnot(is(con, "DBIConnection") || inherits(con, "Pool"))
 
   if (inherits(con, "Pool")) {
@@ -84,22 +94,17 @@ dm_from_con <- function(con = NULL, table_names = NULL, learn_keys = NULL,
   }
 
   if (is_null(table_names)) {
-    src_tbl_names <- get_src_tbl_names(src, ...)
+    src_tbl_names <- get_src_tbl_names(src, ..., names = .names)
   } else {
     src_tbl_names <- table_names
   }
 
-  if (inherits(src_tbl_names, "SQL")) {
-    tbls <-
-      src_tbl_names %>%
-      map(dbplyr::ident_q) %>%
-      map(possibly(tbl, NULL), src = src)
-  } else {
-    tbls <-
-      set_names(src_tbl_names) %>%
-      quote_ids(con) %>%
-      map(possibly(tbl, NULL), src = src)
-  }
+  nms <- purrr::map_chr(src_tbl_names, ~ .x@name[["table"]])
+
+  tbls <-
+    set_names(src_tbl_names, nms) %>%
+    quote_ids(con) %>%
+    map(possibly(tbl, NULL), src = src)
 
   bad <- map_lgl(tbls, is_null)
   if (any(bad)) {
@@ -139,15 +144,9 @@ quote_ids <- function(x, con, schema = NULL) {
   }
 
   if (is_null(schema)) {
-    map(
-      x,
-      ~ dbplyr::ident_q(dbplyr::build_sql(dbplyr::ident(.x), con = con))
-    )
+    map_if(x, ~ !inherits(.x, "Id"), ~ DBI::Id(table = .x))
   } else {
-    map(
-      x,
-      ~ dbplyr::ident_q(schema_if(rep(schema, length(.x)), .x, con))
-    )
+    map_if(x, ~ !inherits(.x, "Id"), ~ schema_if(rep(schema, length(.x)), .x, con)[[1]])
   }
 }
 
