@@ -32,6 +32,7 @@
 #'   # the `dm` from the SQLite DB
 #'   iris_dm_learned <- dm_learn_from_db(src_sqlite)
 #' }
+#' @autoglobal
 dm_learn_from_db <- function(dest, dbname = NA, schema = NULL, name_format = "{table}") {
   # assuming that we will not try to learn from (globally) temporary tables, which do not appear in sys.table
   con <- con_from_src_or_con(dest)
@@ -81,7 +82,8 @@ dm_learn_from_db <- function(dest, dbname = NA, schema = NULL, name_format = "{t
     ungroup() %>%
     pull_tbl()
 
-  tables <- map2(table_info$from, table_info$vars, ~ tbl(con, dbplyr::ident_q(.x), vars = .y))
+  table_info$from_id <- DBI::dbUnquoteIdentifier(con, DBI::SQL(table_info$from))
+  tables <- map2(table_info$from_id, table_info$vars, ~ tbl(con, .x, vars = .y))
   names(tables) <- table_info$dm_name
 
   pks_df <-
@@ -96,9 +98,12 @@ dm_learn_from_db <- function(dest, dbname = NA, schema = NULL, name_format = "{t
     dm_update_zoomed() %>%
     dm_select_tbl(-table_constraints) %>%
     dm_flatten_to_tbl(key_column_usage, .recursive = TRUE) %>%
-    select(constraint_catalog, constraint_schema, constraint_name, dm_name, column_name) %>%
+    select(constraint_catalog, constraint_schema, constraint_name, dm_name, column_name, is_autoincrement) %>%
     group_by(constraint_catalog, constraint_schema, constraint_name, dm_name) %>%
-    summarize(pks = list(tibble(column = list(column_name)))) %>%
+    summarize(pks = list(tibble(
+      column = list(column_name),
+      autoincrement = any(as.logical(is_autoincrement))
+    ))) %>%
     ungroup() %>%
     select(table = dm_name, pks)
 
@@ -109,6 +114,7 @@ dm_learn_from_db <- function(dest, dbname = NA, schema = NULL, name_format = "{t
     dm_update_zoomed() %>%
     dm_zoom_to(key_column_usage) %>%
     semi_join(table_constraints) %>%
+    left_join(table_constraints, select = c(delete_rule)) %>%
     left_join(columns, select = c(column_name, dm_name, table_catalog, table_schema, table_name)) %>%
     dm_update_zoomed() %>%
     dm_select_tbl(-table_constraints) %>%
@@ -135,6 +141,7 @@ dm_learn_from_db <- function(dest, dbname = NA, schema = NULL, name_format = "{t
       constraint_schema,
       constraint_name,
       ordinal_position,
+      delete_rule,
       ref_table = constraint_column_usage.dm_name,
       ref_column = constraint_column_usage.column_name,
       table = key_column_usage.dm_name,
@@ -158,7 +165,16 @@ dm_learn_from_db <- function(dest, dbname = NA, schema = NULL, name_format = "{t
       ref_column = list(ref_column),
       table = if (length(table) > 0) table[[1]] else NA_character_,
       column = list(column),
-      on_delete = "no_action"
+      on_delete = {
+        x <- case_when(
+          delete_rule == "CASCADE" ~ "cascade",
+          .default = "no_action"
+        ) %>% unique()
+        if (!is_empty(x) & !is_scalar_character(x)) {
+          abort("delete_rule for all fk_cols in one constraint_name should be the same")
+        }
+        x
+      }
     ))) %>%
     ungroup() %>%
     select(-(1:3)) %>%
@@ -166,24 +182,30 @@ dm_learn_from_db <- function(dest, dbname = NA, schema = NULL, name_format = "{t
     summarize(fks = list(bind_rows(fks))) %>%
     ungroup()
 
-  def <- new_dm_def(tables, pks_df, fks_df)
+  # FIXME: add uks_df
+  def <- new_dm_def(tables, pks_df, fks_df = fks_df)
   new_dm3(def)
 }
 
 schema_if <- function(schema, table, con, dbname = NULL) {
-  table_sql <- DBI::dbQuoteIdentifier(con, table)
   if (is_null(dbname) || is.na(dbname) || dbname == "") {
-    if_else(
-      are_na(schema),
-      table_sql,
-      # need 'coalesce()' cause in case 'schema' is NA, 'if_else()' also tests
-      # the FALSE option (to see if same class) and then 'dbQuoteIdentifier()' throws an error
-      SQL(paste0(DBI::dbQuoteIdentifier(con, coalesce(schema, "")), ".", table_sql))
+    purrr::map2(
+      schema, table,
+      ~ {
+        if (is.na(.x)) {
+          DBI::Id(table = .y)
+        } else {
+          DBI::Id(schema = .x, table = .y)
+        }
+      }
     )
   } else {
     # 'schema_if()' only used internally (can e.g. be set to default schema beforehand)
     # so IMHO we don't need a formal 'dm_error' here
     if (anyNA(schema)) abort("`schema` must be given if `dbname` is not NULL`.")
-    SQL(paste0(DBI::dbQuoteIdentifier(con, dbname), ".", DBI::dbQuoteIdentifier(con, schema), ".", table_sql))
+    purrr::map2(
+      table, schema,
+      ~ DBI::Id(catalog = dbname, schema = .y, table = .x)
+    )
   }
 }
