@@ -266,3 +266,47 @@ test_that("bogus arguments are rejected", {
       dm_add_fk(a, x, b, x, on_delete = letters)
   })
 })
+
+
+# all foreign keys --------------------------------------------------------------------
+
+test_that("dm_get_all_fks() and order", {
+  dm <- dm_for_filter()
+  fks_all <- dm_get_all_fks(dm)
+  fks_1 <- dm_get_all_fks(dm, "tf_1")
+  fks_3 <- dm_get_all_fks(dm, tf_3)
+  fks_4 <- dm_get_all_fks(dm, "tf_4")
+  fks_6 <- dm_get_all_fks(dm, "tf_6")
+  fks_34 <- dm_get_all_fks(dm, c(tf_3, tf_4))
+  fks_43 <- dm_get_all_fks(dm, c(tf_4, tf_3))
+
+  expect_equal(fks_all, bind_rows(fks_1, fks_3, fks_4, fks_6))
+  expect_equal(fks_34, bind_rows(fks_3, fks_4))
+  expect_equal(fks_43, bind_rows(fks_4, fks_3))
+})
+
+test_that("dm_get_all_fks() with parent_table arg", {
+  expect_snapshot({
+    nyc_comp() %>%
+      dm_get_all_fks(weather)
+
+    nyc_comp() %>%
+      dm_get_all_fks(c("airlines", "weather"))
+
+    # test tidyselect functions for parent_table arg
+    nyc_comp() %>%
+      dm_get_all_fks(ends_with("ports"))
+
+    nyc_comp() %>%
+      dm_get_all_fks(everything())
+  })
+})
+
+test_that("dm_get_all_fks() with parent_table arg fails nicely", {
+  skip_if(packageVersion("tidyselect") > "1.2.0")
+
+  expect_snapshot_error({
+    nyc_comp() %>%
+      dm_get_all_fks(c(airlines, weather, timetable, tabletime))
+  })
+})
