@@ -10,7 +10,7 @@ test_that("table identifiers are quoted", {
       test_table_321 = tibble(b = 2)
     ),
     temporary = FALSE,
-    table_names = ~ DBI::SQL(unique_db_table_name(.x))
+    table_names = ~ unique_db_table_name(.x)
   )
 
   remote_tbl_names_copied <- map_chr(dm_get_tables(test_dm), dbplyr::remote_name)
@@ -32,7 +32,7 @@ test_that("table identifiers are quoted", {
   remote_tbl_names_learned <-
     dm %>%
     dm_get_tables() %>%
-    map_chr(dbplyr::remote_name)
+    map_chr(remote_name_qual)
 
   # `gsub()`, cause schema names are part of the remote_names (also standard schemas "dbo" for MSSQL and "public" for Postgres).
   expect_setequal(gsub("^.*\\.", "", unname(remote_tbl_names_learned)), unclass(DBI::dbQuoteIdentifier(con_db, names(dm))))
@@ -50,11 +50,11 @@ test_that("table identifiers are quoted with learn_keys = FALSE", {
       test_table_321 = tibble(b = 2)
     ),
     temporary = FALSE,
-    table_names = ~ DBI::SQL(unique_db_table_name(.x))
+    table_names = ~ unique_db_table_name(.x)
   )
   remote_tbl_names_copied <- map_chr(
     src_tbls_impl(test_dm),
-    ~ dbplyr::remote_name(test_dm[[.x]])
+    ~ remote_name_qual(test_dm[[.x]])
   )
 
   on.exit({
@@ -68,7 +68,7 @@ test_that("table identifiers are quoted with learn_keys = FALSE", {
   remote_names <-
     dm %>%
     dm_get_tables() %>%
-    map_chr(dbplyr::remote_name)
+    map_chr(remote_name_qual)
 
   con <- dm_get_con(dm)
   expect_equal(gsub("^.*\\.", "", unname(remote_names)), unclass(DBI::dbQuoteIdentifier(con, names(dm))))
